#!/bin/bash -e

export LANG=C

echon() {
	printf "%s" "$@"
}
yesno()
{
	msg="$1"
	def="$2"
	while true ; do
	echon "$msg"
	read answer
	if [ "$answer" ] ; then
		case "$answer" in
		y|Y|yes|YES)
			return 0
			;;
		n|N|no|NO)
			return 1
			;;
		*)
			echo " "
			echo "Error: Invalid response, expected \"yes\" or \"no\"."
			continue
			;;
		esac
	else
		return $def
	fi
	done
}

test `id -u` -ne 0 && echo "Run as root." && exit 1
while getopts "d:u:h" opt; do 
  case $opt in
    \?) OPT_ERROR=1; break;;
    d) arg_target_device="$OPTARG";; # Optional argument: -d /dev/??
    u) arg_uuid="$OPTARG";;          # Optional argument: -u ?????
    h) echo "usage: $0 [-d <target_device>] [-u <uuid>(preferred)]" && exit
  esac
done
if test -n "${arg_target_device}" && test -n "${arg_uuid}"; then
echo "Warning: uuid has been given. target_device will be ignored."
fi
target_device=
if test -n "${arg_uuid}"; then
testline=$(echo "${arg_uuid}"|tr -d [:alnum:]|tr -d \-)
test -n "${testline}" && echo "Error, Invalid argument." && exit 1
target_device_uuid=${arg_uuid}
else
if test -n "${arg_target_device}"; then
if test ! -e "${arg_target_device}"; then
echo "Error, ${arg_target_device} does not exist." && exit 1
else
target_device=${arg_target_device}
fi
else
target_device=`mount|grep "on /boot "|cut -d" " -f1`
test -z "${target_device}" && target_device=`mount|grep "on / "|cut -d" " -f1`
fi
line=`blkid|grep "${target_device}:"`
line=${line#*UUID\=\"*}
line=${line%%\"*}
testline=$(echo "${line}"|tr -d [:alnum:]|tr -d \-)
test -n "${testline}" && echo "Error, Can't get UUID." && exit 1
target_device_uuid=${line}
fi
echo "target_device: ${target_device}"
echo "target_device_uuid: ${target_device_uuid}"
echo "The debconf database will be updated."
if yesno "Proceed? yes or no [n] " 1 ; then
tempfile=$(mktemp)
chmod +x "${tempfile}"
cat>${tempfile}<<EOT
#!/bin/bash -e
. /usr/share/debconf/confmodule
db_go
db_set grub-pc/install_devices "/dev/disk/by-uuid/${target_device_uuid}"
db_get grub-pc/install_devices
db_stop
echo "Updated successfully."
echo 2>&1 "grub-pc/install_devices: \${RET}"
rm "\${0}"
EOT
exec "${tempfile}"
fi
