#!/bin/sh -ex
#
# このスクリプトは特製イニシャルラムディスク作成の為の
# 作業ディレクトリ直下で実行することを前提としています。
# 事前にそのディレクトリに、ベースとなる通常のイニシャルラムディスクが
# 解凍・展開されていることを前提としています。
#

#
# 必要なパッケージの(親環境への)インストール
#
apt-get update
apt-get install binutils
apt-get install openssh-server
apt-get install portmap
apt-get install nfs-common
apt-get install smbfs
apt-get install dosfstools
apt-get install syslinux
apt-get install nmap
apt-get install patch
apt-get install testdisk
apt-get install dpkg-dev
apt-get install hexer

#
# mountallのソースをダウンロードし、 
# パッチを適用してコンパイルして
# カストマイズ版を作成し、
# Minimum Ubuntu ワークRootへの
# インストール
#
# 
../scripts/recompile-mountall.sh

#
# grub1(0.97)のMinimum Ubuntu ワークRootへの
# インストール
#
../scripts/install-grub1.sh


#
# 入れ替えが必要なファイルの削除
#
rm bin/halt
rm bin/reboot
rm bin/poweroff
rm bin/mount
rm bin/dd
rm bin/cpio
rm bin/sh
rm bin/dmesg

#
# スクリプト形式の実行ファイルのコピー
#
echo /bin/which                  |cpio -pdm .
echo /bin/gunzip                 |cpio -pdm .
echo /bin/zcat                   |cpio -pdm .
#echo /bin/setupcon               |cpio -pdm .
echo /usr/bin/savelog            |cpio -pdm .
echo /usr/bin/ldd                |cpio -pdm .
echo /usr/bin/groups             |cpio -pdm .
echo /sbin/dhclient-script       |cpio -pdm .
echo /sbin/mount.smbfs           |cpio -pdm .
echo /sbin/ldconfig              |cpio -pdm .
echo /usr/sbin/service           |cpio -pdm .
echo /usr/sbin/invoke-rc.d       |cpio -pdm .
echo /usr/sbin/gss_destroy_creds |cpio -pdm .
echo /usr/sbin/update-grub2      |cpio -pdm .
echo /usr/sbin/update-grub       |cpio -pdm .
echo /usr/sbin/grub-install      |cpio -pdm .
echo /usr/sbin/upgrade-from-grub-legacy|cpio -pdm .
echo /usr/sbin/grub-set-default  |cpio -pdm .
echo /usr/sbin/grub-reboot       |cpio -pdm .
test -e /usr/sbin/grub-dumpbios && echo /usr/sbin/grub-dumpbios |cpio -pdm .

#
#  /binからバイナリ形式実行ファイルのコピー
#
../utl/copy-execfile-to-newroot.sh /bin/bash         .
../utl/copy-execfile-to-newroot.sh /bin/dmesg        .
../utl/copy-execfile-to-newroot.sh /bin/ls           .
../utl/copy-execfile-to-newroot.sh /bin/readlink     .
../utl/copy-execfile-to-newroot.sh /bin/mount        .
../utl/copy-execfile-to-newroot.sh /bin/umount       .
../utl/copy-execfile-to-newroot.sh /bin/dd           .
../utl/copy-execfile-to-newroot.sh /bin/cat          .
../utl/copy-execfile-to-newroot.sh /bin/mktemp       .
../utl/copy-execfile-to-newroot.sh /bin/grep         .
../utl/copy-execfile-to-newroot.sh /bin/sed          .
../utl/copy-execfile-to-newroot.sh /bin/more         .
../utl/copy-execfile-to-newroot.sh /bin/cp           .
../utl/copy-execfile-to-newroot.sh /bin/mv           .
../utl/copy-execfile-to-newroot.sh /bin/date         .
../utl/copy-execfile-to-newroot.sh /bin/df           .
../utl/copy-execfile-to-newroot.sh /bin/rmdir        .
../utl/copy-execfile-to-newroot.sh /bin/chmod        .
../utl/copy-execfile-to-newroot.sh /bin/ps           .
../utl/copy-execfile-to-newroot.sh /bin/kill         .
../utl/copy-execfile-to-newroot.sh /bin/rm           .
../utl/copy-execfile-to-newroot.sh /bin/bzip2        .
../utl/copy-execfile-to-newroot.sh /bin/tar          .
../utl/copy-execfile-to-newroot.sh /bin/run-parts    .
../utl/copy-execfile-to-newroot.sh /bin/ping         .
../utl/copy-execfile-to-newroot.sh /bin/kill         .
../utl/copy-execfile-to-newroot.sh /bin/stty         .
../utl/copy-execfile-to-newroot.sh /bin/login        .
../utl/copy-execfile-to-newroot.sh /bin/hostname     .
../utl/copy-execfile-to-newroot.sh /bin/su           .
../utl/copy-execfile-to-newroot.sh /bin/mountpoint   .
../utl/copy-execfile-to-newroot.sh /bin/egrep        .
../utl/copy-execfile-to-newroot.sh /bin/chgrp        .
../utl/copy-execfile-to-newroot.sh /bin/chown        .
../utl/copy-execfile-to-newroot.sh /bin/touch        .
../utl/copy-execfile-to-newroot.sh /bin/cpio         .
../utl/copy-execfile-to-newroot.sh /bin/gzip         .
../utl/copy-execfile-to-newroot.sh /bin/echo         .
../utl/copy-execfile-to-newroot.sh /bin/lsmod        .
../utl/copy-execfile-to-newroot.sh /bin/uname        .
../utl/copy-execfile-to-newroot.sh /bin/mknod        .
../utl/copy-execfile-to-newroot.sh /bin/mkdir        .
../utl/copy-execfile-to-newroot.sh /bin/ln           .
../utl/copy-execfile-to-newroot.sh /bin/sync         .
../utl/copy-execfile-to-newroot.sh /bin/dbus-daemon                 .
../utl/copy-execfile-to-newroot.sh /bin/dbus-cleanup-sockets        .
../utl/copy-execfile-to-newroot.sh /bin/dbus-uuidgen                .
../utl/copy-execfile-to-newroot.sh /bin/ip           .

#
#  /usr/binからバイナリ形式実行ファイルのコピー
#
../utl/copy-execfile-to-newroot.sh /usr/bin/basename    .
../utl/copy-execfile-to-newroot.sh /usr/bin/xargs       .
../utl/copy-execfile-to-newroot.sh /usr/bin/mawk        .
../utl/copy-execfile-to-newroot.sh /usr/bin/[           .
../utl/copy-execfile-to-newroot.sh /usr/bin/expr        .
../utl/copy-execfile-to-newroot.sh /usr/bin/dirname     .
../utl/copy-execfile-to-newroot.sh /usr/bin/head        .
../utl/copy-execfile-to-newroot.sh /usr/bin/strings     .
../utl/copy-execfile-to-newroot.sh /usr/bin/cut         .
../utl/copy-execfile-to-newroot.sh /usr/bin/stat        .
../utl/copy-execfile-to-newroot.sh /usr/bin/file        .
../utl/copy-execfile-to-newroot.sh /usr/bin/dircolors   .
../utl/copy-execfile-to-newroot.sh /usr/bin/vim.tiny    .
../utl/copy-execfile-to-newroot.sh /usr/bin/free        .
../utl/copy-execfile-to-newroot.sh /usr/bin/hexdump     .
../utl/copy-execfile-to-newroot.sh /usr/bin/tr          .
../utl/copy-execfile-to-newroot.sh /usr/bin/rsync       .
../utl/copy-execfile-to-newroot.sh /usr/bin/find        .
../utl/copy-execfile-to-newroot.sh /usr/bin/id          .
../utl/copy-execfile-to-newroot.sh /usr/bin/pstree      .
../utl/copy-execfile-to-newroot.sh /usr/bin/strace      .
../utl/copy-execfile-to-newroot.sh /usr/bin/ckbcomp     .
../utl/copy-execfile-to-newroot.sh /usr/bin/tput        .
../utl/copy-execfile-to-newroot.sh /usr/bin/nmap        .
../utl/copy-execfile-to-newroot.sh /usr/bin/ssh         .
../utl/copy-execfile-to-newroot.sh /usr/bin/scp         .
../utl/copy-execfile-to-newroot.sh /usr/bin/ssh-add     .
../utl/copy-execfile-to-newroot.sh /usr/bin/ssh-agent   .
../utl/copy-execfile-to-newroot.sh /usr/bin/ssh-keygen  .
../utl/copy-execfile-to-newroot.sh /usr/bin/ssh-keyscan .
../utl/copy-execfile-to-newroot.sh /usr/bin/sftp        .
../utl/copy-execfile-to-newroot.sh /usr/bin/sudo        .
../utl/copy-execfile-to-newroot.sh /usr/bin/passwd      .
../utl/copy-execfile-to-newroot.sh /usr/bin/netkit-ftp  .
../utl/copy-execfile-to-newroot.sh /usr/bin/tset        .
../utl/copy-execfile-to-newroot.sh /usr/bin/lspci       .
../utl/copy-execfile-to-newroot.sh /usr/bin/test        .
../utl/copy-execfile-to-newroot.sh /usr/bin/env         .
../utl/copy-execfile-to-newroot.sh /usr/bin/du          .
../utl/copy-execfile-to-newroot.sh /usr/bin/diff        .
../utl/copy-execfile-to-newroot.sh /usr/bin/tee         .
../utl/copy-execfile-to-newroot.sh /usr/bin/syslinux    .
../utl/copy-execfile-to-newroot.sh /usr/bin/mtools      .
../utl/copy-execfile-to-newroot.sh /usr/bin/md5sum      .
../utl/copy-execfile-to-newroot.sh /usr/bin/eject       .
../utl/copy-execfile-to-newroot.sh /usr/bin/sort        .
../utl/copy-execfile-to-newroot.sh /usr/bin/clear       .
../utl/copy-execfile-to-newroot.sh /usr/bin/mkfifo       .
../utl/copy-execfile-to-newroot.sh /usr/bin/dbus-send    .
../utl/copy-execfile-to-newroot.sh /usr/bin/dbus-monitor .
../utl/copy-execfile-to-newroot.sh /usr/bin/dbus-launch  .
../utl/copy-execfile-to-newroot.sh /usr/bin/grub-mkimage .
../utl/copy-execfile-to-newroot.sh /usr/bin/grub-mkelfimage .
../utl/copy-execfile-to-newroot.sh /usr/bin/grub-mkfont  .
../utl/copy-execfile-to-newroot.sh /usr/bin/grub-editenv .
../utl/copy-execfile-to-newroot.sh /usr/bin/tail         .
../utl/copy-execfile-to-newroot.sh /usr/bin/dpkg         .
../utl/copy-execfile-to-newroot.sh /usr/bin/wc           .
../utl/copy-execfile-to-newroot.sh /usr/bin/eject        .
../utl/copy-execfile-to-newroot.sh /usr/bin/volname      .
../utl/copy-execfile-to-newroot.sh /usr/bin/hexer        .
../utl/copy-execfile-to-newroot.sh /usr/bin/gettext      .
test -e /usr/bin/grub-mkrelpath && ../utl/copy-execfile-to-newroot.sh /usr/bin/grub-mkrelpath .

#
#  /sbinからバイナリ形式実行ファイルのコピー
#
../utl/copy-execfile-to-newroot.sh /sbin/init              .
../utl/copy-execfile-to-newroot.sh /sbin/initctl           .
../utl/copy-execfile-to-newroot.sh /sbin/fdisk             .
../utl/copy-execfile-to-newroot.sh /sbin/hdparm            .
../utl/copy-execfile-to-newroot.sh /sbin/hwclock           .
../utl/copy-execfile-to-newroot.sh /sbin/modprobe          .
../utl/copy-execfile-to-newroot.sh /sbin/ldconfig.real     .
../utl/copy-execfile-to-newroot.sh /sbin/ifup              .
../utl/copy-execfile-to-newroot.sh /sbin/ifdown            .
../utl/copy-execfile-to-newroot.sh /sbin/ifconfig          .
../utl/copy-execfile-to-newroot.sh /sbin/route             .
../utl/copy-execfile-to-newroot.sh /sbin/telinit           .
../utl/copy-execfile-to-newroot.sh /sbin/getty             .
../utl/copy-execfile-to-newroot.sh /sbin/runlevel          .
../utl/copy-execfile-to-newroot.sh /sbin/sulogin           .
../utl/copy-execfile-to-newroot.sh /sbin/start-stop-daemon .
../utl/copy-execfile-to-newroot.sh /sbin/shutdown          .
../utl/copy-execfile-to-newroot.sh /sbin/reboot            .
../utl/copy-execfile-to-newroot.sh /sbin/sysctl            .
../utl/copy-execfile-to-newroot.sh /sbin/dhclient3         .
../utl/copy-execfile-to-newroot.sh /sbin/blkid             .
../utl/copy-execfile-to-newroot.sh /sbin/mkswap            .
../utl/copy-execfile-to-newroot.sh /sbin/swapon            .
../utl/copy-execfile-to-newroot.sh /sbin/mkfs.ext3         .
../utl/copy-execfile-to-newroot.sh /sbin/mkfs.ext4         .
../utl/copy-execfile-to-newroot.sh /sbin/mkdosfs           .
../utl/copy-execfile-to-newroot.sh /sbin/dosfsck           .
../utl/copy-execfile-to-newroot.sh /sbin/dosfslabel        .
../utl/copy-execfile-to-newroot.sh /sbin/killall5          .
../utl/copy-execfile-to-newroot.sh /sbin/tune2fs           .
../utl/copy-execfile-to-newroot.sh /sbin/mount.nfs         .
../utl/copy-execfile-to-newroot.sh /sbin/portmap           .
../utl/copy-execfile-to-newroot.sh /sbin/pmap_dump         .
../utl/copy-execfile-to-newroot.sh /sbin/pmap_set          .
../utl/copy-execfile-to-newroot.sh /sbin/rpc.statd         .
../utl/copy-execfile-to-newroot.sh /sbin/sm-notify         .
../utl/copy-execfile-to-newroot.sh /sbin/showmount         .
../utl/copy-execfile-to-newroot.sh /sbin/mount.cifs        .
../utl/copy-execfile-to-newroot.sh /sbin/umount.cifs       .
../utl/copy-execfile-to-newroot.sh /sbin/fsck              .
../utl/copy-execfile-to-newroot.sh /sbin/fsck.ext2         .
../utl/copy-execfile-to-newroot.sh /sbin/fsck.ext3         .
../utl/copy-execfile-to-newroot.sh /sbin/iptables          .
../utl/copy-execfile-to-newroot.sh /sbin/iptables-restore  .
../utl/copy-execfile-to-newroot.sh /sbin/iptables-save     .
../utl/copy-execfile-to-newroot.sh /sbin/ip6tables         .
../utl/copy-execfile-to-newroot.sh /sbin/ip6tables-restore .
../utl/copy-execfile-to-newroot.sh /sbin/ip6tables-save    .
../utl/copy-execfile-to-newroot.sh /sbin/logsave           .
../utl/copy-execfile-to-newroot.sh /sbin/upstart-udev-bridge        .

#
#  /usr/sbinからバイナリ形式実行ファイルのコピー
#
../utl/copy-execfile-to-newroot.sh /usr/sbin/sshd              .
../utl/copy-execfile-to-newroot.sh /usr/sbin/nfsstat           .
../utl/copy-execfile-to-newroot.sh /usr/sbin/rpc.gssd          .
../utl/copy-execfile-to-newroot.sh /usr/sbin/rpc.idmapd        .
../utl/copy-execfile-to-newroot.sh /usr/sbin/gss_clnt_send_err .
../utl/copy-execfile-to-newroot.sh /usr/sbin/testdisk          .
../utl/copy-execfile-to-newroot.sh /usr/sbin/photorec          .
../utl/copy-execfile-to-newroot.sh /usr/sbin/grub-setup        .
../utl/copy-execfile-to-newroot.sh /usr/sbin/grub-mkdevicemap  .
../utl/copy-execfile-to-newroot.sh /usr/sbin/grub-probe        .
../utl/copy-execfile-to-newroot.sh /usr/sbin/rsyslogd          .
../utl/copy-execfile-to-newroot.sh /usr/sbin/chroot            .

../utl/copy-execfile-to-newroot.sh /usr/sbin/rpcdebug          .

#
#  /usr/libからバイナリ形式実行ファイルのコピー
#
../utl/copy-execfile-to-newroot.sh /usr/lib/pt_chown           .

#
# Ubuntuのリリースによって構成が異なる部分の処理
#
if file /usr/bin/screen|grep -q "shell script"; then
echo /usr/bin/screen               |cpio -pdm .
../utl/copy-execfile-to-newroot.sh /usr/bin/screen.real .
else
../utl/copy-execfile-to-newroot.sh /usr/bin/screen      .
fi

#
# lddで完全に検索できないライブラリをコピー
#
rm -rf lib/tls
find /lib/tls       |cpio -pdm .

#
# カーネルモジュールを追加
#
find /lib/modules/`uname -r`/kernel/net/netfilter       |cpio -pdm .
find /lib/modules/`uname -r`/kernel/net/bridge/netfilter|cpio -pdm .
find /lib/modules/`uname -r`/kernel/net/ipv4/netfilter  |cpio -pdm .
find /lib/modules/`uname -r`/kernel/net/ipv6/netfilter  |cpio -pdm .
find /lib/modules/`uname -r`/kernel -name "cifs.ko"     |cpio -pdm .
find /lib/modules/`uname -r`/kernel -name "nls_utf8.ko" |cpio -pdm .
depmod -ae -b .

#
# 標準のシンボリックリンクを作成
#
ln -s bash             bin/sh
ln -s ../sbin/killall5 bin/pidof
ln -s vim.tiny         usr/bin/vi
ln -s vim.tiny         usr/bin/editor
ln -s mawk             usr/bin/awk
ln -s netkit-ftp       usr/bin/ftp
ln -s netkit-ftp       usr/bin/pftp
ln -s tset             usr/bin/reset
ln -s mtools           usr/bin/mattrib
ln -s mtools           usr/bin/mbadblocks
ln -s mtools           usr/bin/mcat
ln -s mtools           usr/bin/mcd
ln -s mtools           usr/bin/mclasserase
ln -s mtools           usr/bin/mcopy
ln -s mtools           usr/bin/mdel
ln -s mtools           usr/bin/mdeltree
ln -s mtools           usr/bin/mdir
ln -s mtools           usr/bin/mdu
ln -s mtools           usr/bin/mformat
ln -s mtools           usr/bin/minfo
ln -s mtools           usr/bin/mlabel
ln -s mtools           usr/bin/mmd
ln -s mtools           usr/bin/mmount
ln -s mtools           usr/bin/mmove
ln -s mtools           usr/bin/mpartition
ln -s mtools           usr/bin/mrd
ln -s mtools           usr/bin/mren
ln -s mtools           usr/bin/mshowfat
ln -s mtools           usr/bin/mtoolstest
ln -s mtools           usr/bin/mtype
ln -s mtools           usr/bin/mzip
ln -s md5sum           usr/bin/md5sum.textutils
ln -s initctl          sbin/start
ln -s initctl          sbin/stop
ln -s initctl          sbin/status
ln -s initctl          sbin/reload
ln -s initctl          sbin/restart
ln -s reboot           sbin/halt
ln -s reboot           sbin/poweroff
ln -s mkdosfs          sbin/mkfs.vfat
ln -s dosfsck          sbin/fsck.vfat
ln -s swapon           sbin/swapoff
ln -s mount.nfs        sbin/umount.nfs
ln -s /bin/lsmod       sbin/lsmod
ln -s /bin/ip          sbin/ip
ln -s /usr/sbin/service usr/bin/service

#
# 各ディレクトリを丸ごとコピー
#
find /lib/udev/devices         |cpio -pdm .
find /lib/terminfo             |cpio -pdm .
find /lib/init                 |cpio -pdm .
find /lib/lsb                  |cpio -pdm .
find /lib/security             |cpio -pdm .
find /lib/xtables              |cpio -pdm .
find /lib/dbus-1.0             |cpio -pdm .
find /lib/firmware/`uname -r`/3com   |cpio -pdm .
find /lib/firmware/`uname -r`/acenic |cpio -pdm .
find /lib/firmware/`uname -r`/adaptec|cpio -pdm .
find /lib/firmware/`uname -r`/bnx2   |cpio -pdm .
find /lib/firmware/`uname -r`/cis    |cpio -pdm .
find /lib/firmware/`uname -r`/e100   |cpio -pdm .
find /lib/firmware/`uname -r`/qlogic |cpio -pdm .
find /usr/lib/rsyslog          |cpio -pdm .
find /usr/lib/openssh          |cpio -pdm .
find /etc/pam.d                |cpio -pdm .
find /etc/security             |cpio -pdm .
find /etc/ssh                  |cpio -pdm .
find /etc/sysctl.d             |cpio -pdm .
find /etc/default              |cpio -pdm .
find /etc/udev                 |cpio -pdm .
find /etc/dbus-1               |cpio -pdm .
find /etc/dhcp3                |cpio -pdm .
find /etc/rsyslog.d            |cpio -pdm .
find /usr/lib/locale/en_US.utf8|cpio -pdm .
find /usr/lib/grub/i386-pc     |cpio -pdm .
find /usr/lib/grub-legacy      |cpio -pdm .
find /etc/grub.d               |cpio -pdm .
find /usr/lib/grub/grub-mkconfig_lib|cpio -pdm .
find /usr/lib/grub/update-grub_lib  |cpio -pdm .
find /usr/share/grub           |cpio -pdm .
find /usr/share/file           |cpio -pdm .
find /usr/share/dbus-1         |cpio -pdm .
find /usr/share/nfs-common     |cpio -pdm .

#
# 各・単体ファイルをコピー
#
echo /etc/lsb-base-logging.sh      |cpio -pdm .
echo /usr/share/locale/locale.alias|cpio -pdm .
echo /usr/lib/sftp-server          |cpio -pdm .
echo /usr/lib/syslinux/ldlinux.sys |cpio -pdm .
echo /usr/lib/syslinux/mbr.bin     |cpio -pdm .
echo /etc/rsyslog.conf             |cpio -pdm .

#
# grub2の為のシンボリックリンクを作成
#
ln -s /mnt/boot  boot

#
#  必要なinitスクリプトをコピー
#
test -e /etc/init/console-setup.conf && echo /etc/init/console-setup.conf |cpio -pdm .
echo /etc/init/control-alt-delete.conf  |cpio -pdm .
echo /etc/init/dbus.conf                |cpio -pdm .
echo /etc/init/dmesg.conf               |cpio -pdm .
echo /etc/init/gssd.conf                |cpio -pdm .
echo /etc/init/hostname.conf            |cpio -pdm .
echo /etc/init/hwclock-save.conf        |cpio -pdm .
echo /etc/init/hwclock.conf             |cpio -pdm .
echo /etc/init/idmapd.conf              |cpio -pdm .
echo /etc/init/module-init-tools.conf   |cpio -pdm .
echo /etc/init/mountall-net.conf        |cpio -pdm .
echo /etc/init/mountall-reboot.conf     |cpio -pdm .
echo /etc/init/mountall-shell.conf      |cpio -pdm .
echo /etc/init/mountall.conf            |cpio -pdm .
echo /etc/init/network-interface.conf   |cpio -pdm .
echo /etc/init/networking.conf          |cpio -pdm .
echo /etc/init/portmap.conf             |cpio -pdm .
echo /etc/init/portmap-boot.conf        |cpio -pdm .
echo /etc/init/portmap-wait.conf        |cpio -pdm .
echo /etc/init/procps.conf              |cpio -pdm .
echo /etc/init/rc-sysinit.conf          |cpio -pdm .
echo /etc/init/rc.conf                  |cpio -pdm .
#echo /etc/init/rpc_pipefs.conf          |cpio -pdm .
echo /etc/init/rsyslog.conf             |cpio -pdm .
test -e /etc/init/rsyslog-kmsg.conf && echo /etc/init/rsyslog-kmsg.conf |cpio -pdm .
test -e /etc/init/ssh.conf && echo /etc/init/ssh.conf |cpio -pdm .
echo /etc/init/statd.conf               |cpio -pdm .
echo /etc/init/tty1.conf                |cpio -pdm .
echo /etc/init/udev-finish.conf         |cpio -pdm .
echo /etc/init/udev.conf                |cpio -pdm .
echo /etc/init/udevmonitor.conf         |cpio -pdm .
echo /etc/init/udevtrigger.conf         |cpio -pdm .
echo /etc/init/upstart-udev-bridge.conf |cpio -pdm .

#
#  必要なinit.dスクリプトをコピー
#
echo /etc/init.d/apport               |cpio -pdm .
echo /etc/init.d/bootlogd             |cpio -pdm .
echo /etc/init.d/dbus                 |cpio -pdm .
echo /etc/init.d/dmesg                |cpio -pdm .
echo /etc/init.d/dns-clean            |cpio -pdm .
echo /etc/init.d/gssd                 |cpio -pdm .
test -e /etc/init.d/hal && echo /etc/init.d/hal |cpio -pdm .
echo /etc/init.d/halt                 |cpio -pdm .
echo /etc/init.d/hwclock              |cpio -pdm .
echo /etc/init.d/hwclock-save         |cpio -pdm .
echo /etc/init.d/idmapd               |cpio -pdm .
echo /etc/init.d/kerneloops           |cpio -pdm .
echo /etc/init.d/killprocs            |cpio -pdm .
echo /etc/init.d/module-init-tools    |cpio -pdm .
echo /etc/init.d/networking           |cpio -pdm .
echo /etc/init.d/ondemand             |cpio -pdm .
echo /etc/init.d/portmap              |cpio -pdm .
echo /etc/init.d/portmap-boot         |cpio -pdm .
echo /etc/init.d/portmap-wait         |cpio -pdm .
echo /etc/init.d/procps               |cpio -pdm .
echo /etc/init.d/rc                   |cpio -pdm .
echo /etc/init.d/rc.local             |cpio -pdm .
echo /etc/init.d/rcS                  |cpio -pdm .
echo /etc/init.d/reboot               |cpio -pdm .
#echo /etc/init.d/rpc_pipefs           |cpio -pdm .
echo /etc/init.d/rsyslog              |cpio -pdm .
test -e /etc/init.d/rsyslog-kmsg && echo /etc/init.d/rsyslog-kmsg |cpio -pdm .
echo /etc/init.d/screen-cleanup       |cpio -pdm .
echo /etc/init.d/sendsigs             |cpio -pdm .
echo /etc/init.d/single               |cpio -pdm .
echo /etc/init.d/ssh                  |cpio -pdm .
echo /etc/init.d/statd                |cpio -pdm .
echo /etc/init.d/stop-bootlogd        |cpio -pdm .
echo /etc/init.d/stop-bootlogd-single |cpio -pdm .
echo /etc/init.d/udev                 |cpio -pdm .
echo /etc/init.d/udev-finish          |cpio -pdm .
echo /etc/init.d/udevmonitor          |cpio -pdm .
echo /etc/init.d/udevtrigger          |cpio -pdm .
echo /etc/init.d/umountfs             |cpio -pdm .
echo /etc/init.d/umountnfs.sh         |cpio -pdm .
echo /etc/init.d/umountroot           |cpio -pdm .
#echo /etc/init.d/unattended-upgrades  |cpio -pdm .
echo /etc/init.d/urandom              |cpio -pdm .

#
# rc?.dを丸ごとコピー
#
find /etc/rcS.d       |cpio -pdm .
find /etc/rc0.d       |cpio -pdm .
find /etc/rc1.d       |cpio -pdm .
find /etc/rc2.d       |cpio -pdm .
find /etc/rc3.d       |cpio -pdm .
find /etc/rc4.d       |cpio -pdm .
find /etc/rc5.d       |cpio -pdm .
find /etc/rc6.d       |cpio -pdm .

#
# 参照先のinit.dスクリプトがないシンボリックリンクを削除
#
find etc/rcS.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc0.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc1.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc2.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc3.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc4.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc5.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print
find etc/rc6.d -type l -exec ../utl/remove-dead-symlink.sh {} \; -print

#
# 基本的な/etc以下の単体ファイルをコピー
#
cp -p /etc/ld.so.cache  etc
cp -p /etc/sysctl.conf  etc
cp -p /etc/locale.alias etc
cp -p /etc/login.defs   etc
cp -p /etc/sudoers      etc
cp -p /etc/securetty    etc
cp -p /etc/modules      etc
cp -p /etc/bash.bashrc  etc
cp -p /etc/profile      etc
mkdir -p etc/profile.d

#
# タイムゾーンの設定ファイルをコピー
#
cp -p /usr/share/zoneinfo/Japan etc/localtime

#
# カストマイズしたファイルをコピー
#
cp -p ../contentfiles/rcS.conf                          etc/init
cp -p ../contentfiles/locale                            etc/default
cp -p ../contentfiles/passwd                            etc
cp -p ../contentfiles/shadow                            etc
cp -p ../contentfiles/group                             etc
cp -p ../contentfiles/.bashrc                           .
cp -p ../contentfiles/.bash_profile                     .
cp -p ../contentfiles/extract-backuped-pbr.sh           .
cp -p ../contentfiles/guess-partition-table.sh          .
cp -p ../contentfiles/get-disk_identifier\(ntsig\).sh   .
cp -p ../contentfiles/clear-disk_identifier\(ntsig\).sh .
cp -p ../contentfiles/mkfs.ext3.sh                      .
cp -p ../contentfiles/mkfs.ext4.sh                      .
cp -p ../contentfiles/update_debconf_grub-pc_install_devices.sh .
#cp -p ../contentfiles/mountall                          sbin
cp -p ../contentfiles/grub-mkconfig                     usr/sbin
cp -p ../contentfiles/get-grub-core-modules.sh          usr/bin
rm -f etc/default/grub
cp -p ../contentfiles/grub                              etc/default

#
# ネットワーク関係の整備
#
mkdir -p etc/network/if-down.d etc/network/if-post-down.d etc/network/if-pre-up.d etc/network/if-up.d
echo /etc/network/if-up.d/upstart        |cpio -pdm .
echo /etc/network/if-down.d/upstart      |cpio -pdm .
#echo /etc/network/if-up.d/openssh-server |cpio -pdm . # 有効にしてもいい
cp -p /etc/services      etc
cp -p /etc/protocols     etc
cp -p /etc/rpc           etc
cp -p /etc/shells        etc
cp -p /etc/host.conf     etc
cp -p /etc/nsswitch.conf etc
cp -p ../contentfiles/interfaces      etc/network
cp -p ../contentfiles/interfaces.fixedaddress.sample etc/network
cp -p ../contentfiles/hostname        etc
cp -p ../contentfiles/fstab           etc
touch  etc/resolv.conf
mkdir -p var/lib/dhcp3

#
# iptablesの為
#
cp -p ../contentfiles/iptables etc/init.d
ln -s ../init.d/iptables  etc/rcS.d/S39iptables
ln -s ../init.d/iptables  etc/rc1.d/K39iptables

#
# nfsの為
#
mkdir -p var/lib/nfs/sm
mkdir -p var/lib/nfs/sm.bak
mkdir -p var/lib/nfs/rpc_pipefs
chown -R statd var/lib/nfs

#
# その他の必要なディレクトリを作成
#
mkdir -p var/log var/run
mkdir -p var/lib/dbus
mkdir -p var/lib/urandom

#
# screenの為
#
cp -p /etc/screenrc     etc

#
# fileの為
#
mkdir -p usr/share/misc
ln -s ../file/magic      usr/share/misc/magic
ln -s ../file/magic.mgc  usr/share/misc/magic.mgc
ln -s ../file/magic.mime usr/share/misc/magic.mime

#
# これだけは手動で追加
#
cp -p /usr/lib/libck-connector.so.0 usr/lib

#
# 通常のrootファイルシステムとしても使用可能とする為 
#
mkdir -p proc sys tmp dev var/lock
chmod 1777 tmp

#
# 汎用マウントポイント
#
mkdir mnt

#
# ユーザディレクトリの整備
#
mkdir home
cp -a /etc/skel home/owner
chown -R 1000.users home/owner

#
# MBMの整備
#
cp -a ../mbm-* .
MBMPACKPATH=`ls -d mbm-*`
perl -i -pe "s/^LIBDIR.*$/LIBDIR\=\/${MBMPACKPATH}\/binary/" $MBMPACKPATH/install-mbm-no-install
ln -s $MBMPACKPATH/install-mbm-no-install install-mbm
chown -R 0.0 mbm-*

#
# initスクリプトの修正
# (chrootせずにinitデーモンを走らせるように)
patch -p0 -b < ../patches/init.patch

#
# apparmor初期化スクリプトの削除
#
rm -f scripts/init-bottom/_apparmor

#
# chrootしないことへの対応
#
rm scripts/init-bottom/udev
cp -p ../contentfiles/udev  scripts/init-bottom

#
# もしあったら邪魔なファイルを削除
#
find etc/udev/rules.d -name "*persistent-net.rules" -exec rm {} \; -print

#
# ログイン時のバージョン表示用ファイルの作成
#
VER=`head -1 ../Changelog|sed -e 's/[^0-9\.]//g'`
echo "cat<<EOT">etc/ssh/sshrc
echo "Minimum Ubuntu $VER">>etc/ssh/sshrc
echo "Kernel "`uname -r`" on an "`uname -m`>>etc/ssh/sshrc
echo >>etc/ssh/sshrc
echo "EOT" >>etc/ssh/sshrc
echo "[1;33mMinimum Ubuntu $VER \\l">etc/issue
echo "Kernel "`uname -r`" on an "`uname -m`"[0;39m">>etc/issue
echo >>etc/issue
